@@ -83,7 +83,7 @@ class ChatCompletionsRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _Model: 模型名称，可选值包括 hunyuan-lite、hunyuan-standard、hunyuan-standard-256K、hunyuan-pro、 hunyuan-code、 hunyuan-role、 hunyuan-functioncall、 hunyuan-vision。
+        :param _Model: 模型名称，可选值包括 hunyuan-lite、hunyuan-standard、hunyuan-standard-256K、hunyuan-pro、 hunyuan-code、 hunyuan-role、 hunyuan-functioncall、 hunyuan-vision、 hunyuan-turbo。
 各模型介绍请阅读 [产品概述](https://cloud.tencent.com/document/product/1729/104753) 中的说明。
 
 注意：
@@ -92,8 +92,8 @@ class ChatCompletionsRequest(AbstractModel):
         :param _Messages: 聊天上下文信息。
 说明：
 1. 长度最多为 40，按对话时间从旧到新在数组中排列。
-2. Message.Role 可选值：system、user、assistant、 tool。
-其中，system 角色可选，如存在则必须位于列表的最开始。user（tool） 和 assistant 需交替出现（一问一答），以 user 提问开始，user（tool）提问结束，且 Content 不能为空。Role 的顺序示例：[system（可选） user assistant user assistant user ...]。
+2. Message.Role 可选值：system、user、assistant、 tool（functioncall场景）。
+其中，system 角色可选，如存在则必须位于列表的最开始。user（tool） 和 assistant 需交替出现（一问一答），以 user 提问开始，user（tool）提问结束，其中tool可以连续出现多次，且 Content 不能为空。Role 的顺序示例：[system（可选） user assistant user（tool tool ...） assistant user（tool tool ...） ...]。
 3. Messages 中 Content 总长度不能超过模型输入长度上限（可参考 [产品概述](https://cloud.tencent.com/document/product/1729/104753) 文档），超过则会截断最前面的内容，只保留尾部内容。
         :type Messages: list of Message
         :param _Stream: 流式调用开关。
@@ -133,11 +133,11 @@ class ChatCompletionsRequest(AbstractModel):
 3. 关闭时将直接由主模型生成回复内容，可以降低响应时延（对于流式输出时的首字时延尤为明显）。但在少数场景里，回复效果可能会下降。
 4. 安全审核能力不属于功能增强范围，不受此字段影响。
         :type EnableEnhancement: bool
-        :param _Tools: 可调用的工具列表，仅对 hunyuan-functioncall 模型生效。
+        :param _Tools: 可调用的工具列表，仅对 hunyuan-pro、hunyuan-turbo、hunyuan-functioncall 模型生效。
         :type Tools: list of Tool
         :param _ToolChoice: 工具使用选项，可选值包括 none、auto、custom。
 说明：
-1. 仅对 hunyuan-functioncall 模型生效。
+1. 仅对 hunyuan-pro、hunyuan-turbo、hunyuan-functioncall 模型生效。
 2. none：不调用工具；auto：模型自行选择生成回复或调用工具；custom：强制模型调用指定的工具。
 3. 未设置时，默认值为auto
         :type ToolChoice: str
@@ -153,6 +153,15 @@ class ChatCompletionsRequest(AbstractModel):
         :type Citation: bool
         :param _EnableSpeedSearch: 是否开启极速版搜索，默认false，不开启；在开启且命中搜索时，会启用极速版搜索，流式输出首字返回更快。
         :type EnableSpeedSearch: bool
+        :param _EnableMultimedia: 多媒体开关。
+详细介绍请阅读 [多媒体介绍](https://cloud.tencent.com/document/product/1729/111178) 中的说明。
+说明：
+1. 该参数目前仅对白名单内用户生效，如您想体验该功能请 [联系我们](https://cloud.tencent.com/act/event/Online_service)。
+2. 该参数仅在功能增强（如搜索）开关开启（EnableEnhancement=true）并且极速版搜索开关关闭（EnableSpeedSearch=false）时生效。
+3. hunyuan-lite 无多媒体能力，该参数对 hunyuan-lite 版本不生效。
+4. 未传值时默认关闭。
+5. 开启并搜索到对应的多媒体信息时，会输出对应的多媒体地址，可以定制个性化的图文消息。
+        :type EnableMultimedia: bool
         """
         self._Model = None
         self._Messages = None
@@ -167,6 +176,7 @@ class ChatCompletionsRequest(AbstractModel):
         self._SearchInfo = None
         self._Citation = None
         self._EnableSpeedSearch = None
+        self._EnableMultimedia = None
 
     @property
     def Model(self):
@@ -272,6 +282,14 @@ class ChatCompletionsRequest(AbstractModel):
     def EnableSpeedSearch(self, EnableSpeedSearch):
         self._EnableSpeedSearch = EnableSpeedSearch
 
+    @property
+    def EnableMultimedia(self):
+        return self._EnableMultimedia
+
+    @EnableMultimedia.setter
+    def EnableMultimedia(self, EnableMultimedia):
+        self._EnableMultimedia = EnableMultimedia
+
 
     def _deserialize(self, params):
         self._Model = params.get("Model")
@@ -299,6 +317,7 @@ class ChatCompletionsRequest(AbstractModel):
         self._SearchInfo = params.get("SearchInfo")
         self._Citation = params.get("Citation")
         self._EnableSpeedSearch = params.get("EnableSpeedSearch")
+        self._EnableMultimedia = params.get("EnableMultimedia")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -335,6 +354,11 @@ class ChatCompletionsResponse(AbstractModel):
         :type ModerationLevel: str
         :param _SearchInfo: 搜索结果信息
         :type SearchInfo: :class:`tencentcloud.hunyuan.v20230901.models.SearchInfo`
+        :param _Replaces: 多媒体信息。
+说明：
+1. 可以用多媒体信息替换回复内容里的占位符，得到完整的消息。
+2. 可能会出现回复内容里存在占位符，但是因为审核等原因没有返回多媒体信息。
+        :type Replaces: list of Replace
         :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。本接口为流式响应接口，当请求成功时，RequestId 会被放在 HTTP 响应的 Header "X-TC-RequestId" 中。
         :type RequestId: str
         """
@@ -346,6 +370,7 @@ class ChatCompletionsResponse(AbstractModel):
         self._ErrorMsg = None
         self._ModerationLevel = None
         self._SearchInfo = None
+        self._Replaces = None
         self._RequestId = None
 
     @property
@@ -412,6 +437,14 @@ class ChatCompletionsResponse(AbstractModel):
     def SearchInfo(self, SearchInfo):
         self._SearchInfo = SearchInfo
 
+    @property
+    def Replaces(self):
+        return self._Replaces
+
+    @Replaces.setter
+    def Replaces(self, Replaces):
+        self._Replaces = Replaces
+
     @property
     def RequestId(self):
         return self._RequestId
@@ -441,6 +474,12 @@ class ChatCompletionsResponse(AbstractModel):
         if params.get("SearchInfo") is not None:
             self._SearchInfo = SearchInfo()
             self._SearchInfo._deserialize(params.get("SearchInfo"))
+        if params.get("Replaces") is not None:
+            self._Replaces = []
+            for item in params.get("Replaces"):
+                obj = Replace()
+                obj._deserialize(item)
+                self._Replaces.append(obj)
         self._RequestId = params.get("RequestId")
 
 
@@ -977,6 +1016,79 @@ class GetTokenCountResponse(AbstractModel):
         self._RequestId = params.get("RequestId")
 
 
+class History(AbstractModel):
+    """混元生图多轮对话历史记录。
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _ChatId: 对话的 ID，用于唯一标识一轮对话
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ChatId: str
+        :param _Prompt: 原始输入的 Prompt 文本
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Prompt: str
+        :param _RevisedPrompt: 扩写后的 Prompt 文本
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RevisedPrompt: str
+        :param _Seed: 生成图的随机种子
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Seed: int
+        """
+        self._ChatId = None
+        self._Prompt = None
+        self._RevisedPrompt = None
+        self._Seed = None
+
+    @property
+    def ChatId(self):
+        return self._ChatId
+
+    @ChatId.setter
+    def ChatId(self, ChatId):
+        self._ChatId = ChatId
+
+    @property
+    def Prompt(self):
+        return self._Prompt
+
+    @Prompt.setter
+    def Prompt(self, Prompt):
+        self._Prompt = Prompt
+
+    @property
+    def RevisedPrompt(self):
+        return self._RevisedPrompt
+
+    @RevisedPrompt.setter
+    def RevisedPrompt(self, RevisedPrompt):
+        self._RevisedPrompt = RevisedPrompt
+
+    @property
+    def Seed(self):
+        return self._Seed
+
+    @Seed.setter
+    def Seed(self, Seed):
+        self._Seed = Seed
+
+
+    def _deserialize(self, params):
+        self._ChatId = params.get("ChatId")
+        self._Prompt = params.get("Prompt")
+        self._RevisedPrompt = params.get("RevisedPrompt")
+        self._Seed = params.get("Seed")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class ImageUrl(AbstractModel):
     """具体的图片内容
 
@@ -1156,7 +1268,7 @@ class Message(AbstractModel):
         :param _ToolCallId: 当role为tool时传入，标识具体的函数调用
 注意：此字段可能返回 null，表示取不到有效值。
         :type ToolCallId: str
-        :param _ToolCalls: 模型生成的工具调用，仅 hunyuan-functioncall 模型支持
+        :param _ToolCalls: 模型生成的工具调用，仅 hunyuan-pro 或者 hunyuan-functioncall 模型支持
 注意：此字段可能返回 null，表示取不到有效值。
         :type ToolCalls: list of ToolCall
         """
@@ -1233,6 +1345,297 @@ class Message(AbstractModel):
         
 
 
+class Multimedia(AbstractModel):
+    """多媒体详情
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _Type: 多媒体类型，可选值包括 image、music、album、playlist。
+说明：
+1. image：图片；music：单曲，类型为单曲时，会返回详细歌手和歌曲信息；album：专辑；playlist：歌单。
+2. 当 type 为 music、album、playlist 时，需要配合 [QQ音乐SDK](https://developer.y.qq.com/) 使用。
+        :type Type: str
+        :param _Url: 多媒体地址。
+说明：
+1. type 为 image 时，地址为图片的预览地址；其他类型时，地址为封面图地址。
+        :type Url: str
+        :param _JumpUrl: 多媒体详情地址。
+说明：
+1. 仅 type 为 image 时，该字段有值。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type JumpUrl: str
+        :param _Title: 名称。
+说明：
+1. type 为 image 时，该字段为空。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Title: str
+        :param _Desc: 描述。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Desc: str
+        :param _Singer: 歌手名称。
+说明：
+1. 仅 type 为 music 时，该字段有值。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Singer: str
+        :param _Ext: 歌曲详情。
+说明：
+1. 仅 type 为 music 时，该字段有值。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Ext: :class:`tencentcloud.hunyuan.v20230901.models.SongExt`
+        """
+        self._Type = None
+        self._Url = None
+        self._JumpUrl = None
+        self._Title = None
+        self._Desc = None
+        self._Singer = None
+        self._Ext = None
+
+    @property
+    def Type(self):
+        return self._Type
+
+    @Type.setter
+    def Type(self, Type):
+        self._Type = Type
+
+    @property
+    def Url(self):
+        return self._Url
+
+    @Url.setter
+    def Url(self, Url):
+        self._Url = Url
+
+    @property
+    def JumpUrl(self):
+        return self._JumpUrl
+
+    @JumpUrl.setter
+    def JumpUrl(self, JumpUrl):
+        self._JumpUrl = JumpUrl
+
+    @property
+    def Title(self):
+        return self._Title
+
+    @Title.setter
+    def Title(self, Title):
+        self._Title = Title
+
+    @property
+    def Desc(self):
+        return self._Desc
+
+    @Desc.setter
+    def Desc(self, Desc):
+        self._Desc = Desc
+
+    @property
+    def Singer(self):
+        return self._Singer
+
+    @Singer.setter
+    def Singer(self, Singer):
+        self._Singer = Singer
+
+    @property
+    def Ext(self):
+        return self._Ext
+
+    @Ext.setter
+    def Ext(self, Ext):
+        self._Ext = Ext
+
+
+    def _deserialize(self, params):
+        self._Type = params.get("Type")
+        self._Url = params.get("Url")
+        self._JumpUrl = params.get("JumpUrl")
+        self._Title = params.get("Title")
+        self._Desc = params.get("Desc")
+        self._Singer = params.get("Singer")
+        if params.get("Ext") is not None:
+            self._Ext = SongExt()
+            self._Ext._deserialize(params.get("Ext"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class QueryHunyuanImageChatJobRequest(AbstractModel):
+    """QueryHunyuanImageChatJob请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _JobId: 任务 ID。
+        :type JobId: str
+        """
+        self._JobId = None
+
+    @property
+    def JobId(self):
+        return self._JobId
+
+    @JobId.setter
+    def JobId(self, JobId):
+        self._JobId = JobId
+
+
+    def _deserialize(self, params):
+        self._JobId = params.get("JobId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class QueryHunyuanImageChatJobResponse(AbstractModel):
+    """QueryHunyuanImageChatJob返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _JobStatusCode: 当前任务状态码：
+1：等待中、2：运行中、4：处理失败、5：处理完成。
+        :type JobStatusCode: str
+        :param _JobStatusMsg: 当前任务状态：排队中、处理中、处理失败或者处理完成。
+
+        :type JobStatusMsg: str
+        :param _JobErrorCode: 任务处理失败错误码。
+
+        :type JobErrorCode: str
+        :param _JobErrorMsg: 任务处理失败错误信息。
+
+        :type JobErrorMsg: str
+        :param _ChatId: 本轮对话的 ChatId，ChatId 用于唯一标识一轮对话。
+一个对话组中，最多支持进行100轮对话。
+每轮对话数据有效期为7天，到期后 ChatId 失效，有效期内的历史对话数据可通过 History 查询，如有长期使用需求请及时保存输入输出数据。
+        :type ChatId: str
+        :param _ResultImage: 生成图 URL 列表，有效期7天，请及时保存。
+        :type ResultImage: list of str
+        :param _ResultDetails: 结果 detail 数组，Success 代表成功。
+
+        :type ResultDetails: list of str
+        :param _History: 本轮对话前置的历史对话数据（不含生成图）。
+        :type History: list of History
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self._JobStatusCode = None
+        self._JobStatusMsg = None
+        self._JobErrorCode = None
+        self._JobErrorMsg = None
+        self._ChatId = None
+        self._ResultImage = None
+        self._ResultDetails = None
+        self._History = None
+        self._RequestId = None
+
+    @property
+    def JobStatusCode(self):
+        return self._JobStatusCode
+
+    @JobStatusCode.setter
+    def JobStatusCode(self, JobStatusCode):
+        self._JobStatusCode = JobStatusCode
+
+    @property
+    def JobStatusMsg(self):
+        return self._JobStatusMsg
+
+    @JobStatusMsg.setter
+    def JobStatusMsg(self, JobStatusMsg):
+        self._JobStatusMsg = JobStatusMsg
+
+    @property
+    def JobErrorCode(self):
+        return self._JobErrorCode
+
+    @JobErrorCode.setter
+    def JobErrorCode(self, JobErrorCode):
+        self._JobErrorCode = JobErrorCode
+
+    @property
+    def JobErrorMsg(self):
+        return self._JobErrorMsg
+
+    @JobErrorMsg.setter
+    def JobErrorMsg(self, JobErrorMsg):
+        self._JobErrorMsg = JobErrorMsg
+
+    @property
+    def ChatId(self):
+        return self._ChatId
+
+    @ChatId.setter
+    def ChatId(self, ChatId):
+        self._ChatId = ChatId
+
+    @property
+    def ResultImage(self):
+        return self._ResultImage
+
+    @ResultImage.setter
+    def ResultImage(self, ResultImage):
+        self._ResultImage = ResultImage
+
+    @property
+    def ResultDetails(self):
+        return self._ResultDetails
+
+    @ResultDetails.setter
+    def ResultDetails(self, ResultDetails):
+        self._ResultDetails = ResultDetails
+
+    @property
+    def History(self):
+        return self._History
+
+    @History.setter
+    def History(self, History):
+        self._History = History
+
+    @property
+    def RequestId(self):
+        return self._RequestId
+
+    @RequestId.setter
+    def RequestId(self, RequestId):
+        self._RequestId = RequestId
+
+
+    def _deserialize(self, params):
+        self._JobStatusCode = params.get("JobStatusCode")
+        self._JobStatusMsg = params.get("JobStatusMsg")
+        self._JobErrorCode = params.get("JobErrorCode")
+        self._JobErrorMsg = params.get("JobErrorMsg")
+        self._ChatId = params.get("ChatId")
+        self._ResultImage = params.get("ResultImage")
+        self._ResultDetails = params.get("ResultDetails")
+        if params.get("History") is not None:
+            self._History = []
+            for item in params.get("History"):
+                obj = History()
+                obj._deserialize(item)
+                self._History.append(obj)
+        self._RequestId = params.get("RequestId")
+
+
 class QueryHunyuanImageJobRequest(AbstractModel):
     """QueryHunyuanImageJob请求参数结构体
 
@@ -1381,6 +1784,56 @@ class QueryHunyuanImageJobResponse(AbstractModel):
         self._RequestId = params.get("RequestId")
 
 
+class Replace(AbstractModel):
+    """多媒体占位符替换信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _Id: 占位符序号
+        :type Id: str
+        :param _Multimedia: 多媒体详情
+        :type Multimedia: list of Multimedia
+        """
+        self._Id = None
+        self._Multimedia = None
+
+    @property
+    def Id(self):
+        return self._Id
+
+    @Id.setter
+    def Id(self, Id):
+        self._Id = Id
+
+    @property
+    def Multimedia(self):
+        return self._Multimedia
+
+    @Multimedia.setter
+    def Multimedia(self, Multimedia):
+        self._Multimedia = Multimedia
+
+
+    def _deserialize(self, params):
+        self._Id = params.get("Id")
+        if params.get("Multimedia") is not None:
+            self._Multimedia = []
+            for item in params.get("Multimedia"):
+                obj = Multimedia()
+                obj._deserialize(item)
+                self._Multimedia.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class SearchInfo(AbstractModel):
     """搜索结果信息
 
@@ -1538,6 +1991,184 @@ class SetPayModeResponse(AbstractModel):
         self._RequestId = params.get("RequestId")
 
 
+class SongExt(AbstractModel):
+    """歌曲详情。具体含义参考  [QQ音乐SDK](https://developer.y.qq.com/)
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _SongId: 歌曲id
+        :type SongId: int
+        :param _SongMid: 歌曲mid
+        :type SongMid: str
+        :param _Vip: 歌曲是否为vip。1：vip歌曲； 0：普通歌曲。
+        :type Vip: int
+        """
+        self._SongId = None
+        self._SongMid = None
+        self._Vip = None
+
+    @property
+    def SongId(self):
+        return self._SongId
+
+    @SongId.setter
+    def SongId(self, SongId):
+        self._SongId = SongId
+
+    @property
+    def SongMid(self):
+        return self._SongMid
+
+    @SongMid.setter
+    def SongMid(self, SongMid):
+        self._SongMid = SongMid
+
+    @property
+    def Vip(self):
+        return self._Vip
+
+    @Vip.setter
+    def Vip(self, Vip):
+        self._Vip = Vip
+
+
+    def _deserialize(self, params):
+        self._SongId = params.get("SongId")
+        self._SongMid = params.get("SongMid")
+        self._Vip = params.get("Vip")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class SubmitHunyuanImageChatJobRequest(AbstractModel):
+    """SubmitHunyuanImageChatJob请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _Prompt: 本轮对话的文本描述。
+提交一个任务请求对应发起一轮生图对话，每轮对话中可输入一条 Prompt，生成一张图像，支持通过多轮输入 Prompt 来不断调整图像内容。
+推荐使用中文，最多可传1024个 utf-8 字符。
+输入示例：
+<li> 第一轮对话：一颗红色的苹果 </li>
+<li> 第二轮对话：将苹果改为绿色 </li>
+<li> 第三轮对话：苹果放在桌子上 </li>
+        :type Prompt: str
+        :param _ChatId: 上传上一轮对话的 ChatId，本轮对话将在指定的上一轮对话结果基础上继续生成图像。
+如果不传代表新建一个对话组，重新开启一轮新的对话。
+一个对话组中，最多支持进行100轮对话。
+        :type ChatId: str
+        :param _LogoAdd: 为生成结果图添加显式水印标识的开关，默认为1。  
+1：添加。  
+0：不添加。  
+其他数值：默认按1处理。  
+建议您使用显著标识来提示结果图使用了 AI 绘画技术，是 AI 生成的图片。
+        :type LogoAdd: int
+        :param _LogoParam: 标识内容设置。
+默认在生成结果图右下角添加“图片由 AI 生成”字样，您可根据自身需要替换为其他的标识图片。
+        :type LogoParam: :class:`tencentcloud.hunyuan.v20230901.models.LogoParam`
+        """
+        self._Prompt = None
+        self._ChatId = None
+        self._LogoAdd = None
+        self._LogoParam = None
+
+    @property
+    def Prompt(self):
+        return self._Prompt
+
+    @Prompt.setter
+    def Prompt(self, Prompt):
+        self._Prompt = Prompt
+
+    @property
+    def ChatId(self):
+        return self._ChatId
+
+    @ChatId.setter
+    def ChatId(self, ChatId):
+        self._ChatId = ChatId
+
+    @property
+    def LogoAdd(self):
+        return self._LogoAdd
+
+    @LogoAdd.setter
+    def LogoAdd(self, LogoAdd):
+        self._LogoAdd = LogoAdd
+
+    @property
+    def LogoParam(self):
+        return self._LogoParam
+
+    @LogoParam.setter
+    def LogoParam(self, LogoParam):
+        self._LogoParam = LogoParam
+
+
+    def _deserialize(self, params):
+        self._Prompt = params.get("Prompt")
+        self._ChatId = params.get("ChatId")
+        self._LogoAdd = params.get("LogoAdd")
+        if params.get("LogoParam") is not None:
+            self._LogoParam = LogoParam()
+            self._LogoParam._deserialize(params.get("LogoParam"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class SubmitHunyuanImageChatJobResponse(AbstractModel):
+    """SubmitHunyuanImageChatJob返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _JobId: 任务 ID。
+        :type JobId: str
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self._JobId = None
+        self._RequestId = None
+
+    @property
+    def JobId(self):
+        return self._JobId
+
+    @JobId.setter
+    def JobId(self, JobId):
+        self._JobId = JobId
+
+    @property
+    def RequestId(self):
+        return self._RequestId
+
+    @RequestId.setter
+    def RequestId(self, RequestId):
+        self._RequestId = RequestId
+
+
+    def _deserialize(self, params):
+        self._JobId = params.get("JobId")
+        self._RequestId = params.get("RequestId")
+
+
 class SubmitHunyuanImageJobRequest(AbstractModel):
     """SubmitHunyuanImageJob请求参数结构体
 
